<?php


// Survey database interface class as intermediate for storing data from the site to the RDF database 
require_once 'rdfConstants.php';

// Include RAP Library to write RDF files
include(RDFAPI_INCLUDE_DIR . "RDFAPI.php");

/**
 * Description of QuestionCreationDatabaseInterface
 *
 * @author basvannuland
 */
class QuestionCreationDatabaseInterface {
   
    protected $questionRDFWriter;
    protected $questionRDFReader;
    
    public function __construct()
    {
        $this->questionRDFWriter = new QuestionRDFWriter();
        $this->questionRDFReader = new QuestionRDFReader();
    }
    
    public function setQuestionInfo($question)
    {
        $qCode = $question['questionCode'];
        $qTitle = $question['questionTitle'];
        $qDescription = $question['questionDescription'];
        $qType = $question['questionType'];
        $qCategory = $question['questionCategory'];

        $qAnswers = array();
        $aNumber = 1;
        while (isset($question['ans'.$aNumber]))
        {
            $qAnswers[] = $question['ans'.$aNumber];

            $aNumber++;
        }

        if($this->checkQuestionCodeExists($qCode))
        {
            return 'Question code (' . $qCode . ') already in use. Please try a new code.';
        }
        else {
            $this->questionRDFWriter->createQuestion($qTitle,$qDescription,$qType,$qCode,$qCategory,$qAnswers);
            $this->questionRDFWriter->saveQuestions(); 
            return 'Question saved';
        }         
    }
    
    public function getQuestionInfo($qCode)
    {
        $questionInfo - array();
        
        $questionTitleObject = $this->questionRDFReader->readQuestionTitle($qCode);
        $questionInfo['questionTitle'] = $questionTitleObject[0]['?questionTitle']->label;

        $questionDescriptionObject = $this->questionRDFReader->readQuestionDescription($qCode);
        $questionInfo['questionDescription'] = $questionDescriptionObject[0]['?questionDescription']->label;

        $questionTypeObject = $this->questionRDFReader->readQuestionType($qCode);
        $questionInfo['questionType'] = $questionTypeObject[0]['?questionType']->label;
        
        $questionCategoryObject = $this->questionRDFReader->readQuestionCategory($qCode);
        $questionInfo['questionCategory'] = $questionTypeObject[0]['?questionCategory']->label;

        $resultAnswers = $this->questionRDFReader->readQuestionAnswers($qCode);

        if ($resultAnswers != null)
        {
            for($aNumber = 1;$aNumber<=sizeof($resultAnswers);$aNumber++)
            {
                $questionInfo['ans'.$aNumber] = $resultAnswers[$aNumber-1]['?answerDescription']->label;
            }
        }
    }
    
    public function getExistingQuestions()
    {
        $questions = array();

        $resultQuestions = $this->questionRDFReader->readQuestionCodes();
        $this->questionRDFReader->reloadQuestions();
        if ($resultQuestions != null)
        {
            foreach ($resultQuestions as $questionCodeObject)
            {
                $questionCode = $questionCodeObject['?questionCode']->label;
                $questionTitle = $this->questionRDFReader->readQuestionTitle($questionCode);
                $questions[$questionCode] = $questionTitle[0]['?questionTitle']->label;
            }
        }

        return $questions;
    }
    
    public function checkQuestionCodeExists($qCode)
    {
        $result = false;

        $questionCodes = $this->questionRDFReader->readQuestionCodes();
        
        if ($questionCodes != null)
        {
            foreach($questionCodes as $questionCode)
            {
                $code = $questionCode['?questionCode']->label;
                if(!strcmp($code ,$qCode))
                {
                    $result = true;
                    break;
                }
            }
        }

        return $result;
    }
}

?>
